=================
django-cte-forest
=================

.. image:: https://travis-ci.org/matthiask/django-cte-forest.svg?branch=master
    :target: https://travis-ci.org/matthiask/django-cte-forest

django-cte-forest implements efficient adjacency list trees using Django
and PostgreSQL Common Table Expressions (CTE).

**Note!** This is a friendly fork of django-cte-trees_ by Alexis Petrounias
which introduces support for Python 3 and recent Django versions.

You'll find additional details and information in the documentation_ or
on the original authors webpage on django-cte-trees_

.. _django-cte-trees: http://petrounias.org/software/django-cte-trees/
.. _documentation: https://django-cte-forest.readthedocs.io/
